@@ -25,6 +25,8 @@ if not Movie.is_available():
     SKIP_EXAMPLES.extend(["make_movie_live.py", "make_movie_storage.py"])
 if not module_available("napari"):
     SKIP_EXAMPLES.extend(["tracker_interactive", "show_3d_field_interactively"])
+if not module_available("h5py"):
+    SKIP_EXAMPLES.extend(["trajectory_io"])
 
 
 @pytest.mark.slow
@@ -75,7 +77,7 @@ def test_jupyter_notebooks(path, tmp_path):
 
     # adjust python environment
     my_env = os.environ.copy()
-    my_env["PYTHONPATH"] = str(PACKAGE_PATH) + ":" + my_env["PYTHONPATH"]
+    my_env["PYTHONPATH"] = str(PACKAGE_PATH) + ":" + my_env.get("PYTHONPATH", "")
 
     outfile = tmp_path / os.path.basename(path)
     sp.check_call(
